import {Component} from '@angular/core'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {EmployeeService} from '../../services/employee.service'
import {Employee} from '../../../shared/model/employee'
import {ActivatedRoute, Router} from '@angular/router'
import {FormBuilder, FormControl, FormGroup, Validators} from '@angular/forms'
import {ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-password-edit',
  templateUrl: './password-edit.component.html',
  styleUrls: ['./password-edit.component.sass']
})
export class PasswordEditComponent extends ErrorHandlingComponent {
  employee: Employee | null

  form: FormGroup
  passwordControl = new FormControl(null, Validators.compose([Validators.required, Validators.minLength(8)]))

  constructor(
    private employeeService: EmployeeService,
    private formBuilder: FormBuilder,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    const id = parseInt(this.activatedRoute.snapshot.paramMap.get('id'))
    this.subscribeEntityById(
      this.employeeService,
      id,
      employee => this.employee = employee,
      '/employee/list'
    )

    this.form = this.formBuilder.group({
      password: this.passwordControl
    })
  }

  submit() {
    if (this.form.valid) {
      this.subscribeAndNavigate(
        this.employeeService.updatePassword(this.employee.id, this.passwordControl.value),
        '/employee/list'
      )
    }
  }
}
