import {Component, ViewChild} from '@angular/core'
import {FormBuilder, FormControl, FormGroup, Validators} from '@angular/forms'
import {GroupService} from '../../services/group.service'
import {ActivatedRoute, Router} from '@angular/router'
import {PermissionsFieldComponent} from '../../../shared/components/permissions-field/permissions-field.component'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-add',
  templateUrl: './add.component.html',
  styleUrls: ['./add.component.sass']
})
export class AddComponent extends ErrorHandlingComponent {
  @ViewChild('permissionsField', {static: true}) permissionsField: PermissionsFieldComponent

  form: FormGroup
  nameControl: FormControl

  constructor(
    private formBuilder: FormBuilder,
    private groupService: GroupService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    this.nameControl = new FormControl(null, Validators.compose([Validators.required, Validators.minLength(3)]))
    this.form = this.formBuilder.group({
      name: this.nameControl
    })
  }

  submit() {
    if (this.form.valid && this.permissionsField.valid()) {
      this.subscribeAndNavigate(
        this.groupService.save(this.nameControl.value, this.permissionsField.allEnabledPermissions),
        '/group/list'
      )
    }
  }
}
